@@ -19,9 +19,7 @@ def cli():
 @cli.command()
 def test():
     """Run unittests for the nomnomdata-engine module"""
-    import pytest
-
-    pytest.main(["--pyargs", "nomnomdata.engine"])
+    pass
 
 
 cli.add_command(run)
